==> dimcli-0.5.4-py2.py3-none-any.whl: dimcli/tests/quicktest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-


"""
simple test queries [for DEVELOPMENT  / not part of official tests]

$ pip instal -e .
$ dimcli_quicktest 1

"""

import click 
from .. import *
from ..shortcuts import *

import requests

@click.command()
@click.argument('test_number', nargs=1)
def main(test_number=1):
    
    
    test_number = int(test_number)

    if test_number == 1:
        # res= dslquery("""search publications for "graphene" return publications""")
        # print(res.as_dataframe_authors())
        # print(res.as_dataframe_authors_affiliations())
        # print(res.as_dataframe_funders())
        res= dslquery("""search grants return grants[basics+investigator_details]""")
        print(res.as_dataframe_funders())
        print(res.as_dataframe_investigators())

    elif test_number == 2:
        res = dslquery("""search publications where journal.title="nature medicine" return publications[doi+FOR] limit 1000""")
        print("Query results for standard query: ")
        print(" ==> res['stats']: ", res['stats'])
        print(" ==> len(res['publications']): ", len(res['publications']))
        print(" ==> len([x for x in res.publications if 'FOR' in x]): ", len([x for x in res.publications if 'FOR' in x]))
        print("Now Normalizing the FOR key...")
        normalize_key("FOR", res.publications)
        print(" ==> len([x for x in res.publications if 'FOR' in x]): ", len([x for x in res.publications if 'FOR' in x]))       



if __name__ == '__main__':
    main()

==> dimcli-0.5.6.2-py2.py3-none-any.whl: dimcli/tests/quicktest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-


"""
simple test queries [for DEVELOPMENT  / not part of official tests]

$ pip instal -e .
$ dimcli_quicktest 1

"""

import click 
from .. import *
from ..shortcuts import *

import requests

@click.command()
@click.argument('test_number', nargs=1)
def main(test_number=1):
    
    login()

    test_number = int(test_number)

    if test_number == 1:
        res = dslquery("search publications where year=2018 return icecreams")
        print("NOW a BAD query: search publications where year=2018 return icecreams")
        print("Query TOT results: ", res.total_count)
        print("Query errors: ", res.errors_string)

    elif test_number == 2:
        res = dslquery("""search publications where journal.title="nature medicine" return publications[doi+FOR] limit 1000""")
        print("Query results for standard query: ")
        print(" ==> res['stats']: ", res['stats'])
        print(" ==> len(res['publications']): ", len(res['publications']))
        print(" ==> len([x for x in res.publications if 'FOR' in x]): ", len([x for x in res.publications if 'FOR' in x]))
        print("Now Normalizing the FOR key...")
        normalize_key("FOR", res.publications)
        print(" ==> len([x for x in res.publications if 'FOR' in x]): ", len([x for x in res.publications if 'FOR' in x]))       

    elif test_number == 3:
        res = dslquery("""search publications for "乳がん" return publications""")
        print(" ==> res['stats']: ", res['stats'])


if __name__ == '__main__':
    main()
